#
# Licence GPL v3.
#
# Copyright Chris Johns (chrisj@rtems.org)
#
import optparse
import os
import pq
import pqconfig
import sys
import time

def output(file, text):
    print >> output, text

def remove(node):
    if os.path.isdir(node):
        os.rmdir(node)
    else:
        os.remove(node)

def queue_get_source(running, stdout, stderr, source, src):
    pos = source.find(':')
    if pos < 0:
        print >> sys.stderr, 'invalid source definition:', source
        sys.exit(1)
    source_type = source[:pos]
    source_cmd = source[pos:]
    if source_type == 'copy':
        if not os.path.isdir(source_type):
            print >> sys.stderr, 'cannot find source directory:', source_cmd
            sys.exit(1)
        try:
            shutils.copytree(source_cmd, src)
        except Error, e:
            print >> sys.stderr, 'source copy failed', e
            sys.exit(1)
    elif source_type == 'cvs':
        pos = source_cmd.rfind(':')
        if pos < 0:
            print >> sys.stderr, 'invalid source definition:', source
            sys.exit(1)
        cvsroot = source_cmd[:pos]
        cvsmodule = source_cmd[pos:]
        pq.command('cvs -d ' + cvsroot + ' co -d src ' + cvsmodule,
                   workspace,
                   stdout,
                   stderr)

def queue_build(base, data, workspace, source, targets, patch):
    if patch:
        ps = patch.split(':')
        if len(ps) != 2:
            print >> sys.stderr, 'invalid patch definition:', patch
            sys.exit(1)
        patch_opts = ps[0]
        patch_file = ps[1]
        if not os.path.isfile(patch_file):
            print >> sys.stderr, 'cannot find patch file:', patch_file
            sys.exit(1)

    if not targets:
        pqconfig.build_targets()
    pqconfig.set_build_paths()
    if not os.path.isdir(workspace):
        os.mkdir(workspace)

    src = os.path.join(workspace, 'src')
    install = os.path.join(workspace, 'build')

    running = open(os.path.join(workspace, 'running'), 'w')
    stdout = open(os.path.join(workpsace, 'stdout.txt'), 'w')
    stderr = open(os.path.join(workpsace, 'stderr.txt'), 'w')

    output(running, base + '-' + str(os.getpid()))
    output(stdout, 'Patch Queue Build:', time.ctime())
    output(stderr, 'Patch Queue Build:', time.ctime())
    
    output(running, 'cleaning')
    remove(src)
    remove(install)
    for t in targets:
        remove(os.path.join(workspace, t))

    output(running, '')
    

        
#
# Command line options.
#
cl_options = [
    # Standard options
    optparse.make_option('-d', action = 'store', type = 'string', 
                         dest = 'data', default = os.environ['HOME'],
                         help = 'Specify the data directory'),
    optparse.make_option('-w', action = 'store', type = 'string', 
                         dest = 'workspace', default = None,
                         help = 'Specify the workspace directory'),
    optparse.make_option('-s', action = 'store', type = 'string', 
                         dest = 'source', default = None,
                         help = 'Specify the source directory'),
    optparse.make_option('-t', action = 'store', type = 'string', 
                         dest = 'targets', default = None,
                         help = 'List of comma seperated targets'),
    optparse.make_option('-c', action = 'store', type = 'string',
                         dest = 'config',
                         default = os.environ['HOME'] + '/.pq-config',
                         help = 'Configration file name to read')
]

def user_main(base, argv):
    (options, config, data, workspace, source, targets) = \
        pq.parse_std_args(argv, cl_options)
    if not options.output:
        print >> sys.stderr, 'no output directory specified'
        sys.exit(1)
    queue_build(base, data, workspace, source, targets, None)
