#
# Licence GPL v3.
#
# Copyright Chris Johns (chrisj@rtems.org)
#
import optparse
import os
import sys
import pq
import pqconfig
import pqgetch

def queue_inspect(base, data, workspace, source, targets, edit):
    for target in targets:
        try:
            errors = pq.errors(base, data, source, pqconfig.source_find)
            stdout = open(pqconfig.build_output(workspace, target))
            errors.load_stdout(target, stdout)
            stdout.close()
        except IOError, e:
            print >> sys.stderr, "cannot open the target", \
                pqconfig.build_output(workspace, target) + ":", target
        for error in errors.walk_errs():
            if errors.check_all(target, error['error'].error):
                continue
            pq.error_source_print(error['error'], error['dup'], source)
            print
            if edit:
                print '   Q-Quit  A-All Ignore  T-Target Ignore  B-Baseline F-Fix  N-Next ? ',
                while True:
                    try:
                        k = str(pqgetch.getch).lower()
                        print '%s' % (k),
                    except KeyboardInterrupt:
                        print
                        print 'User abort'
                        return
                    if k == 'q' or ord(k[:1]) == 3:
                        print
                        print 'Quitting'
                        print
                        return
                    elif k == 'a':
                        print
                        print 'All targets', error.type, 'added'
                        print
                        errors.add('user', 'all', error.error)
                        break
                    elif k == 't':
                        print
                        print pq.target_name(target, 1), 'target', error.type, 'added'
                        print
                        errors.add('user', target, error.error)
                        break
                    elif k == 'b':
                        print
                        print pq.target_name(target, 1), 'target', error.type, 'added to baseline'
                        print
                        errors.add('baseline', target, error.error)
                        break
                    elif k == 'f':
                        print
                        print 'Flagged to fix', error.type
                        print
                        errors.add('fix', target, error.error)
                        break
                    elif k == 'n' or k == ' ' or k == '\r':
                        print
                        print
                        break
    
#
# Command line options.
#
cl_options = [
    optparse.make_option('-V', action = 'store_true', dest='version',
                         default = False,
                         help = 'Show the builder version'),
    optparse.make_option('-v', action = 'store_true', dest = 'verbose',
                         default = False,
                         help = 'Verbose messages and tracing'),
    optparse.make_option('-e', action = 'store_true', dest = 'edit',
                         default = False,
                         help = 'Display the status'),
    optparse.make_option('-t', action = 'store', type = 'string', 
                         dest = 'targets', default = None,
                         help = 'List of comma seperated targets'),
    optparse.make_option('-c', action = 'store', type = 'string',
                         dest = 'config',
                         default = None,
                         help = 'Configration file name to read')
]

def user_main(base, argv):
    config = os.environ['HOME'] + '/.pq-config';
    cmd_opts = optparse.OptionParser(option_list = cl_options)
    (options, args) = cmd_opts.parse_args(args=argv)
    data = os.environ['HOME']
    workspace = '/home/chrisj/rtems/pq'
    source = os.path.join(workspace, 'src')
    if options.targets:
        targets = options.targets.split(',')
    else:
        targets = pq.target_list(workspace)
    queue_inspect(base, data, workspace, source, targets, options.edit)
